@@ -40,6 +40,9 @@
 #' @importFrom ISOweek ISOweek2date
 #' @export
 jpinfect_read_confirmed <- function(path, type = NULL, ...) {
+  # Return path location
+  message("Current working directory: ", getwd())
+
   # Single file: Check if it's a file but not a directory
   if (file.exists(path) && !dir.exists(path)) {
     return(.jpinfect_read_excel(path, ...))
@@ -57,7 +60,7 @@ jpinfect_read_confirmed <- function(path, type = NULL, ...) {
   }
 
   # Invalid path
-  stop("Invalid path: must be either a file or directory")
+  stop("Invalid path: no file or directory could be located. Please verify that the specified path is correct.")
 }
 
 
@@ -97,6 +100,16 @@ jpinfect_read_confirmed <- function(path, type = NULL, ...) {
     stop("The 'file_path' is empty. Please specify a valid file path.")
   }
 
+  # file size check
+  if (!(nzchar(Sys.getenv("JPINFECT_SKIP_SIZE_CHECK")) || Sys.getenv("CI") == "true")) {
+    file_size <- file.info(file_path)$size
+    if (!is.na(file_size) && file_size < 2000000) {
+      stop(paste("The file size is unusually small (< 2000 KB) and may be corrupted.\n",
+                 "This may indicate a failed or incomplete download.\n",
+                 "Please re-run jpinfect_get_confirmed() to re-download the file."))
+    }
+  }
+
   message("Processing...", appendLF = FALSE)
 
   # year check
@@ -289,6 +302,18 @@ jpinfect_read_confirmed <- function(path, type = NULL, ...) {
     stop(paste0("Cannot found dataset in \"", directory, "\""))
   }
 
+  # file size check
+  if (!(nzchar(Sys.getenv("JPINFECT_SKIP_SIZE_CHECK")) || Sys.getenv("CI") == "true")) {
+    valid_files <- local_files[file.info(local_files)$size >= 2000000]
+    invalid_files <- setdiff(local_files, valid_files)
+    if (length(invalid_files) > 0) {
+      stop(paste0("The following files are unusually small (< 2000 KB) and may be corrupted:\n",
+                  paste(invalid_files, collapse = "\n"),
+                  "\nThis may indicate a failed or incomplete download.\n",
+                  "\nPlease re-run jpinfect_get_confirmed() to re-download them.\n"))
+    }
+  }
+
   message("Processing ", length(local_files), " files:\n")
 
   message(paste(local_files, collapse = "\n"))
